API
===

.. module:: socketsundso

WebSocket Handling Endpoint
---------------------------

.. automodule:: socketsundso.endpoints
   :members:
   :undoc-members:
   :show-inheritance:


Models
------

.. automodule:: socketsundso.models
   :members:
   :undoc-members:
   :show-inheritance:


Handler
-------

.. automodule:: socketsundso.handler
   :members:
   :undoc-members:
   :show-inheritance:
